@@ -24,17 +24,17 @@ describe 'tripleo::profile::base::logging::rsyslog::file_input' do
     'include ::rsyslog::server'
   end
 
+  let :params do {
+    'sources' => [
+      {'file' => '/path/to/foo.log', 'tag' => 'foo'},
+      {'file' => '/path/to/bar.log', 'tag' => 'bar', 'startmsg.regex' => 'baz'}
+    ],
+    'default_startmsg' => 'test'
+  }
+  end
+
   shared_examples_for 'tripleo::profile::base::logging::rsyslog::file_input' do
     context 'with basic parameters to configure rsyslog file inputs' do
-      let :params do {
-        'sources' => [
-          {'file' => '/path/to/foo.log', 'tag' => 'foo'},
-          {'file' => '/path/to/bar.log', 'tag' => 'bar', 'startmsg.regex' => 'baz'}
-        ],
-        'default_startmsg' => 'test'
-      }
-      end
-
       it 'should configure the given file inputs' do
         should contain_concat__fragment('rsyslog::component::input::foobar_foo').with({
           :target => '/etc/rsyslog.d/50_rsyslog.conf',
@@ -46,21 +46,6 @@ describe 'tripleo::profile::base::logging::rsyslog::file_input' do
         })
       end
     end
-
-    context 'with non-array sources to configure rsyslog file input' do
-      let :params do {
-        'sources' => {'file' => '/path/to/foo.log', 'tag' => 'foo'},
-        'default_startmsg' => 'test'
-      }
-      end
-
-      it 'should configure the given file inputs' do
-        should contain_concat__fragment('rsyslog::component::input::foobar_foo').with({
-          :target => '/etc/rsyslog.d/50_rsyslog.conf',
-          :content => foo_log_conf,
-        })
-      end
-    end
   end
 
   on_supported_os.each do |os, facts|
